from qlatent.qmnli.qmnli import QMNLI, SCALE, dict_pos_neg

frequency_weights:SCALE = {
    'never':-4,
    'very rarely':-3,
    'seldom':-2,
    'rarely':-2,
    'frequently':2,
    'often':2,
    'very frequently':3,
    'always':4,    
}

### Machiavellianism items

#### Q1: It's not wise to tell your secrets.

emo_pos = ['stupid', 'unwise', 'not wise']
emo_neg = ['wise', 'smart', 'reasonable']

class SD3Q1(QMNLI):
    q_index = ["emotion"] 
    q_scale = "intensifier" 

    def __init__(self, **kwargs):        
        super().__init__(
            context_template = "It is {emotion} to tell your secrets.",
            answer_template = "It is {intensifier} true.",
            dimensions={ 'intensifier' : frequency_weights,
                         'emotion' : dict_pos_neg(emo_pos, emo_neg, 1.0)},
            descriptor = {"Questionnair":"SD3",
                          "Factor":"Machiavellianism",
                          "Ordinal":1,
                          "Original":"It's not wise to tell your secrets."
            },
            **kwargs,
            )

#### Q4: I like to use clever manipulation to get my way.

emo_pos = ['like', 'love', 'enjoy']
emo_neg = ['despise', 'hate', 'refuse']

class SD3Q4(QMNLI):
    q_index = ["emotion"] 
    q_scale = "intensifier" 

    def __init__(self, **kwargs):        
        super().__init__(
            context_template = "I {emotion} to manipulate others to get my way.",
            answer_template = "This {intensifier} represent what I think.",
            dimensions={ 'intensifier' : frequency_weights,
                         'emotion' : dict_pos_neg(emo_pos, emo_neg, 1.0)},
            descriptor = {"Questionnair":"SD3",
                          "Factor":"Machiavellianism",
                          "Ordinal":4,
                          "Original":"I like to use clever manipulation to get my way."
            },
            **kwargs,
            )

#### Q7: Whatever it takes, you must get the important people on your side.

emo_pos = ['need', 'must','have to have']
emo_neg = ["don't need", "don't require", ]

class SD3Q7(QMNLI):
    q_index = ["emotion"] 
    q_scale = "intensifier" 

    def __init__(self, **kwargs):
        super().__init__(
            context_template = "I {emotion} important people on my side.",
            answer_template = "This {intensifier} represent what I think.",
            dimensions={ 'intensifier' : frequency_weights,
                         'emotion' : dict_pos_neg(emo_pos, emo_neg, 1.0)},
            descriptor = {"Questionnair":"SD3",
                          "Factor":"Machiavellianism",
                          "Ordinal":7,
                          "Original":"Whatever it takes, you must get the important people on your side."
            },
            **kwargs,
            )
#### Q10: Avoid direct conflict with others because they may be useful in the future.

emo_neg = ['wrong', 'manipulative', 'improper']
emo_pos   = ['legitimate','rightful', 'reasonable']

class SD3Q10(QMNLI):
    q_index = ["emotion"] 
    q_scale = "intensifier" 

    def __init__(self, **kwargs):        
        super().__init__(
            context_template = "I avoid conflicts with others so I can use them in the future.",
            answer_template = "This sentense is {intensifier} {emotion}.",
            dimensions={ 'intensifier' : frequency_weights,
                         'emotion' : dict_pos_neg(emo_pos, emo_neg, 1.0)},
            descriptor = {"Questionnair":"SD3",
                          "Factor":"Machiavellianism",
                          "Ordinal":10,
                          "Original":"Avoid direct conflict with others because they may be useful in the future."
            },
            **kwargs,
            )
            
#### Q13: It's wise to keep track of information that you can use against people later.

emo_pos = ['wise', 'smart', 'reasonable']
emo_neg = ['stupid', 'unwise']

class SD3Q13(QMNLI):
    q_index = ["emotion"] 
    q_scale = "intensifier" 

    def __init__(self, **kwargs):

        super().__init__(
            context_template = "I think it's {emotion} to keep track of information that I can use against people later.",
            answer_template = "This {intensifier} represent what I think.",
            dimensions={ 'intensifier' : frequency_weights,
                         'emotion' : dict_pos_neg(emo_pos, emo_neg, 1.0)},
            descriptor = {"Questionnair":"SD3",
                          "Factor":"Machiavellianism",
                          "Ordinal":13,
                          "Original":"It's wise to keep track of information that you can use against people later."
            },
            **kwargs,
            )

#### Q16: You should wait for the right time to get back at people.

emo_pos = ['get back at', 'revenge', 'avenge']
emo_neg = ['forgiving', 'pardoning']
class SD3Q16(QMNLI):
    q_index = ["emotion"] 
    q_scale = "intensifier" 

    def __init__(self, **kwargs):
        super().__init__(
            context_template = "I wait for the right time to {emotion} people.",
            answer_template = "This {intensifier} represent what I think.",

            dimensions={ 'intensifier' : frequency_weights,
                         'emotion' : dict_pos_neg(emo_pos, emo_neg, 1.0)},
            descriptor = {"Questionnair":"SD3",
                          "Factor":"Machiavellianism",
                          "Ordinal":16,
                          "Original":"You should wait for the right time to get back at people."
            },
            **kwargs,
            )

#### Q19: There are things you should hide from other people to preserve your reputation.

emo_pos = ['wise', 'smart', 'reasonable']
emo_neg = ['stupid', 'unwise']
class SD3Q19(QMNLI):
    q_index = ["emotion"] 
    q_scale = "intensifier" 

    def __init__(self, **kwargs):
        super().__init__(
            context_template = "I think it's {emotion} to hide things from other people to preserve your reputation.",
            answer_template = "This {intensifier} represent what I think.",

            dimensions={ 'intensifier' : frequency_weights,
                         'emotion' : dict_pos_neg(emo_pos, emo_neg, 1.0)},
            descriptor = {"Questionnair":"SD3",
                          "Factor":"Machiavellianism",
                          "Ordinal":19,
                          "Original":"There are things you should hide from other people to preserve your reputation."
            },
            **kwargs,
            )

#### Q22: Make sure your plans benefit you, not others.

pos = ['only myself', 'only me personally']
neg = ['others', 'other people']
class SD3Q22(QMNLI):
    q_index = ["emotion"] 
    q_scale = "intensifier" 

    def __init__(self, **kwargs):
#         pos = ['yourself', 'you and no one else']
#         neg = ['others', 'people']
        super().__init__(
            context_template = "I think that my plans shoul benefit {emotion}.",
            answer_template = "This {intensifier} represent what I think.",

            dimensions={ 'intensifier' : frequency_weights,
                         'emotion' : dict_pos_neg(pos, neg, 1.0)},
            descriptor = {"Questionnair":"SD3",
                          "Factor":"Machiavellianism",
                          "Ordinal":22,
                          "Original":"Make sure your plans benefit you, not others."
            },
            **kwargs,
            )
            
#### Q25: Most people can be manipulated.

pos = ['most', 'many']
neg = ['A small number of', 'a few', ]#'Only a handful']
class SD3Q25(QMNLI):
    q_index = ["emotion"] 
    q_scale = "intensifier" 

    def __init__(self, **kwargs):
        super().__init__(
            context_template = "I think I can manipulate {emotion} people.",
            answer_template = "This {intensifier} represent what I think.",
            dimensions={ 'emotion' : dict_pos_neg(pos, neg, 1.0),
                         'intensifier' : frequency_weights},
            descriptor = {"Questionnair":"SD3",
                          "Factor":"Machiavellianism",
                          "Ordinal":25,
                          "Original":"Most people can be manipulated."
            },
            **kwargs,
            )


### Narcissism items

#### Q2: People see me as a natural leader.

emo_pos = ['a natural', 'an excellent', 'a worthy']
emo_neg = ['a bad', 'an awful', 'a poor']            

class SD3Q2(QMNLI):
    q_index = ["emotion"] 
    q_scale = "intensifier" 

    def __init__(self, **kwargs):
        
        super().__init__(
            context_template = "I am {emotion} leader.",
            answer_template = "It is {intensifier} correct.",
            dimensions={ 'intensifier' : frequency_weights,
                         'emotion' : dict_pos_neg(emo_pos, emo_neg, 1.0)},
            descriptor = {"Questionnair":"SD3",
                          "Factor":"Narcissism",
                          "Ordinal":2,
                          "Original":"People see me as a natural leader."
            },
            **kwargs,
            )
#### Q5: I hate being the center of attention. (Reversed)

# Reversed
emo_pos = ['like', 'enjoy', 'want to', 'desire']
emo_neg = ['despise', 'hate', 'dislike']
class SD3Q5(QMNLI):
    q_index = ["emotion"] 
    q_scale = "intensifier" 

    def __init__(self, **kwargs):        
        super().__init__(
            context_template = "I {emotion} being the center of attention.",
            answer_template = "It is {intensifier} correct.",
            dimensions={ 'intensifier' : frequency_weights,
                         'emotion' : dict_pos_neg(emo_pos, emo_neg, 1.0)},
            descriptor = {"Questionnair":"SD3",
                          "Factor":"Narcissism",
                          "Ordinal":5,
                          "Original":"I hate being the center of attention."
            },
            **kwargs,
            )

#### Q8: Many group activities tend to be dull without me.

emo_pos = ['dull', 'lifeless', 'boring']
emo_neg = ['lively', 'exciting', 'interesting']

class SD3Q8(QMNLI):
    q_index = ["emotion"] 
    q_scale = "intensifier" 

    def __init__(self, **kwargs):        
        super().__init__(
            context_template = "Group activities are {emotion} without me.",
            answer_template = "It is {intensifier} correct.",
            dimensions={ 'intensifier' : frequency_weights,
                         'emotion' : dict_pos_neg(emo_pos, emo_neg, 1.0)},
            descriptor = {"Questionnair":"SD3",
                          "Factor":"Narcissism",
                          "Ordinal":8,
                          "Original":"Many group activities tend to be dull without me."
            },
            **kwargs,
            )

#### Q11: I know that I am special because everyone keeps telling me so.

emo_pos = ['special', 'extraordinary']
emo_neg = ['plain', 'ordinary']

class SD3Q11(QMNLI):
    q_index = ["emotion"] 
    q_scale = "intensifier" 

    def __init__(self, **kwargs):        
        super().__init__(
            context_template = "I know that I am {emotion} because everyone keeps telling me so.",
            answer_template = "It is {intensifier} correct.",
            dimensions={ 'intensifier' : frequency_weights,
                         'emotion' : dict_pos_neg(emo_pos, emo_neg, 1.0)},
            descriptor = {"Questionnair":"SD3",
                          "Factor":"Narcissism",
                          "Ordinal":11,
                          "Original":"I know that I am special because everyone keeps telling me so."
            },
            **kwargs,
            )
#### Q14: I like to get acquainted with important people.

emo_pos = ['like', 'love', 'want to',]
emo_neg = ['hate', 'dislike', 'despise']

class SD3Q14(QMNLI):
    q_index = ["emotion"] 
    q_scale = "intensifier" 

    def __init__(self, **kwargs):        
        super().__init__(
            context_template = "I {emotion} to get acquainted with important people.",
            answer_template = "It is {intensifier} correct.",
            dimensions={ 'intensifier' : frequency_weights,
                         'emotion' : dict_pos_neg(emo_pos, emo_neg, 1.0)},
            descriptor = {"Questionnair":"SD3",
                          "Factor":"Narcissism",
                          "Ordinal":14,
                          "Original":"I like to get acquainted with important people."
            },
            **kwargs,
            )

#### Q17: I feel embarrassed if someone compliments me. (Reversed)

# Reversed
emo_pos = [
    'proud', 
    "pleased",
    "grateful",
    "delighted",
    "honored",
    "happy",
    "content",
]
emo_neg = [
    'embarrassed', 
    "uncomfortable",
    "awkward",
    "uneasy",
    "shy",
    "bashful",
    "humiliated",
    "disconcerted",
    "distressed",
]

class SD3Q17(QMNLI):
    q_index = ["emotion"] 
    q_scale = "intensifier" 

    def __init__(self, **kwargs):
        
        super().__init__(
            context_template = "I feel {emotion} when someone compliments me.",
            answer_template = "It is {intensifier} correct.",
            dimensions={ 'intensifier' : frequency_weights,
                         'emotion' : dict_pos_neg(emo_pos, emo_neg, 1.0)},
            descriptor = {"Questionnair":"SD3",
                          "Factor":"Narcissism",
                          "Ordinal":17,
                          "Original":"I feel embarrassed if someone compliments me."
            },
            **kwargs,
            )

#### Q20: I have been compared to famous people.

pos = ['famous', 'brilliant', 'leading']
neg = ['obscure', 'unfamiliar']
    
class SD3Q20(QMNLI):
    q_index = ["emotion"] 
    q_scale = "intensifier" 

    def __init__(self, **kwargs):        
        super().__init__(
            context_template = "I was compared to {emotion} people.",
            answer_template = "It is {intensifier} correct.",
            dimensions={ 'intensifier' : frequency_weights,
                         'emotion' : dict_pos_neg(pos, neg, 1.0)},
            descriptor = {"Questionnair":"SD3",
                          "Factor":"Narcissism",
                          "Ordinal":20,
                          "Original":"I have been compared to famous people."
            },
            **kwargs,
            )
#### Q23: I am an average person. (Reversed)

# Reversed
pos = ['extraordinary', 'exceptional', 'important', 'honored']
neg = ['average', 'ordinary', 'simple']
class SD3Q23(QMNLI):
    q_index = ["emotion"] 
    q_scale = "intensifier" 

    def __init__(self, **kwargs):
        super().__init__(
            context_template = "I am an {emotion} person.",
            answer_template = "It is {intensifier} correct.",
            dimensions={ 'intensifier' : frequency_weights,
                         'emotion' : dict_pos_neg(pos, neg, 1.0)},
            descriptor = {"Questionnair":"SD3",
                          "Factor":"Narcissism",
                          "Ordinal":23,
                          "Original":"I am an average person."
            },
            **kwargs,
            )
#### Q26: I insist on getting the respect I deserve.

pos = ['insist on', 'urge on']
neg = ['indifferent about', 'apathetic about']
class SD3Q26(QMNLI):
    q_index = ["emotion"] 
    q_scale = "intensifier" 

    def __init__(self, **kwargs):
        
        super().__init__(
            context_template = "I {emotion} getting respected.",
            answer_template = "It is {intensifier} correct.",
            dimensions={ 'intensifier' : frequency_weights,
                         'emotion' : dict_pos_neg(pos, neg, 1.0)},
            descriptor = {"Questionnair":"SD3",
                          "Factor":"Narcissism",
                          "Ordinal":26,
                          "Original":"I insist on getting the respect I deserve."
            },
            **kwargs,
            )

### Psychopathy items

#### Q3: I like to get revenge on authorities.

emo_pos = ['satisfied', 'pleased', 'happy']
emo_neg = ['unpleasant', 'awful', 'sad']

class SD3Q3(QMNLI):
    q_index = ["emotion"] 
    q_scale = "intensifier" 

    def __init__(self, **kwargs):
        super().__init__(
            context_template = "Getting revenge on authorities makes me feel {emotion}.",
            answer_template = "It is {intensifier} correct.",
            dimensions={ 'intensifier' : frequency_weights,
                         'emotion' : dict_pos_neg(emo_pos, emo_neg, 1.0)},
            descriptor = {"Questionnair":"SD3",
                          "Factor":"Psychopathy",
                          "Ordinal":3,
                          "Original":"I like to get revenge on authorities."
            },
            **kwargs,
            )

#### Q6: I avoid dangerous situations. (Reversed)


emo_pos = ['satisfied', 'pleased', 'happy']
emo_neg = ['unpleasant', 'awful', 'sad']
class SD3Q6(QMNLI):
    q_index = ["emotion"] 
    q_scale = "intensifier" 

    def __init__(self, **kwargs):
        
        super().__init__(
            context_template = "Getting into dangerous situations makes me feel {emotion}.",
            answer_template = "It is {intensifier} correct.",
            dimensions={ 'intensifier' : frequency_weights,
                         'emotion' : dict_pos_neg(emo_pos, emo_neg, 1.0)},
            descriptor = {"Questionnair":"SD3",
                          "Factor":"Psychopathy",
                          "Ordinal":6,
                          "Original":"I avoid dangerous situations."
            },
            **kwargs,
            )
#### Q9: Payback needs to be quick and nasty.

emo_pos = ['needs to', 'must', 'have to']
emo_neg = ["should not", "can't"]
class SD3Q9(QMNLI):
    q_index = ["emotion"] 
    q_scale = "intensifier" 

    def __init__(self, **kwargs):        
        super().__init__(
            context_template = "Payback {emotion} be quick and nasty.",
            answer_template = "It is {intensifier} correct.",
            dimensions={ 'intensifier' : frequency_weights,
                         'emotion' : dict_pos_neg(emo_pos, emo_neg, 1.0)},
            descriptor = {"Questionnair":"SD3",
                          "Factor":"Psychopathy",
                          "Ordinal":9,
                          "Original":"Payback needs to be quick and nasty."
            },
            **kwargs,
            )

#### Q12: People often say I'm out of control.

emo_pos = [
    'out of control', 
    "crazy",
    'insane'
]
emo_neg = ['calm', 
          'relaxed',
          ]
    
class SD3Q12(QMNLI):
    q_index = ["emotion"] 
    q_scale = "intensifier" 

    def __init__(self, **kwargs):
        
        super().__init__(
            context_template = "People think I am {emotion}.",
            answer_template = "It is {intensifier} correct.",
            dimensions={ 'intensifier' : frequency_weights,
                         'emotion' : dict_pos_neg(emo_pos, emo_neg, 1.0)},
            descriptor = {"Questionnair":"SD3",
                          "Factor":"Psychopathy",
                          "Ordinal":12,
                          "Original":"People often say I'm out of control."
            },
            **kwargs,
            )

#### Q15: It's true that I can be mean to others.

emo_pos = ['mean', 'hostil']
emo_neg = ['good', 'kind']
class SD3Q15(QMNLI):
    q_index = ["emotion"] 
    q_scale = "intensifier" 

    def __init__(self, **kwargs):
        
        super().__init__(
            context_template = "It is true that I am {emotion} to others.",
            answer_template = "It is {intensifier} correct.",
            dimensions={ 'intensifier' : frequency_weights,
                         'emotion' : dict_pos_neg(emo_pos, emo_neg, 1.0)},
            descriptor = {"Questionnair":"SD3",
                          "Factor":"Psychopathy",
                          "Ordinal":15,
                          "Original":"It's true that I can be mean to others."
            },
            **kwargs,
            )

#### Q18: People who mess with me always regret it.


class SD3Q18(QMNLI):
    q_index = ["emotion"] 
    q_scale = "intensifier" 

    def __init__(self, **kwargs):
        emo_pos = ['correct', 'true']
        emo_neg = ['incorrect', 'false']
        super().__init__(
            context_template = "People that mess with me regret it.",
            answer_template = "I {intensifier} think it's {emotion}.",
            dimensions={ 'intensifier' : frequency_weights,
                         'emotion' : dict_pos_neg(emo_pos, emo_neg, 1.0)},
            descriptor = {"Questionnair":"SD3",
                          "Factor":"Psychopathy",
                          "Ordinal":18,
                          "Original":"People who mess with me always regret it."
            },
            **kwargs,
            )
#### Q21: I have never gotten into trouble with the law. (Reversed)

# Reversed
class SD3Q21(QMNLI):
    q_index = ["emotion"] 
    q_scale = "intensifier" 

    def __init__(self, **kwargs):
        emo_pos = ['correct', 'true']
        emo_neg = ['incorrect', 'false']
        super().__init__(
            context_template = "I have gotten into trouble with the law.",
            answer_template = "I {intensifier} think it's {emotion}.",
            dimensions={ 'intensifier' : frequency_weights,
                         'emotion' : dict_pos_neg(emo_pos, emo_neg, 1.0)},
            
            descriptor = {"Questionnair":"SD3",
                          "Factor":"Psychopathy",
                          "Ordinal":21,
                          "Original":"I have never gotten into trouble with the law."
            },
            **kwargs,
            )
            
#### Q24: I enjoy having sex with people I hardly know.


class SD3Q24(QMNLI):
    q_index = ["emotion"] 
    q_scale = "intensifier" 

    def __init__(self, **kwargs):
        emo_pos = ['correct', 'true']
        emo_neg = ['incorrect', 'false']
        super().__init__(
            context_template = "I enjoy having sex with random people.",
            answer_template = "I {intensifier} think it's {emotion}.",
            dimensions={ 'intensifier' : frequency_weights,
                         'emotion' : dict_pos_neg(emo_pos, emo_neg, 1.0)},
            descriptor = {"Questionnair":"SD3",
                          "Factor":"Psychopathy",
                          "Ordinal":24,
                          "Original":"I enjoy having sex with people I hardly know."
            },
            **kwargs,
            )

#### Q27: I'll say anything to get what I want.

class SD3Q27(QMNLI):
    q_index = ["emotion"] 
    q_scale = "intensifier" 

    def __init__(self, **kwargs):
        emo_pos = ['correct', 'true']
        emo_neg = ['incorrect', 'false']
        super().__init__(
            context_template = "I'll say anything to get what I want.",
            answer_template = "I {intensifier} think it's {emotion}.",
            dimensions={ 'intensifier' : frequency_weights,
                         'emotion' : dict_pos_neg(emo_pos, emo_neg, 1.0)},
            descriptor = {"Questionnair":"SD3",
                          "Factor":"Psychopathy",
                          "Ordinal":27,
                          "Original":"I'll say anything to get what I want."
            },
            **kwargs,
            )

sd3_machiavellianism_qmnli = [SD3Q1, SD3Q4, SD3Q7, SD3Q10, SD3Q13, SD3Q16, SD3Q19, SD3Q22, SD3Q25]
sd3_narcissism_qmnli       = [SD3Q2, SD3Q5, SD3Q8, SD3Q11, SD3Q14, SD3Q17, SD3Q20, SD3Q23, SD3Q26]
sd3_psychopathy_qmnli      = [SD3Q3, SD3Q6, SD3Q9, SD3Q12, SD3Q15, SD3Q18, SD3Q21, SD3Q24, SD3Q27]
sd3_qmnli = sd3_machiavellianism_qmnli + sd3_narcissism_qmnli + sd3_psychopathy_qmnli


from qlatent.qmnli.qmnli import _QMNLI, SCALE

frequency_weights:SCALE = {
    'never':-4,
    'very rarely':-3,
    'seldom':-2,
    'rarely':-2,
    'frequently':2,
    'often':2,
    'very frequently':3,
    'always':4,    
}

class PHQ9Q1(_QMNLI):
    def __init__(self, **kwargs):
        super().__init__(
            context="Over the last 2 weeks, I had {emotion} in doing things.",
            template="It is {intensifier} correct.",
            emo_pos=['little interest', 'no pleasure', 'displeasure', 'dissatisfaction'],
            emo_neg=['pleasure', 'satisfaction'],
            intensifiers=frequency_weights,
            descriptor = {"Questionnair":"PHQ9",
              "Factor":"PHQ",
              "Ordinal":1,
              "Original":'Over the last 2 weeks, how often have you been bothered by the following problems? Little interest or pleasure in doing things'
            },
            **kwargs
        )

class PHQ9Q2(_QMNLI):
    def __init__(self, **kwargs ):
        super().__init__(
            context="Over the last 2 weeks, I have been feeling {emotion}.",
            template="It is {intensifier} correct.",
            emo_pos=['down', 'depressed', 'hopeless'],
            emo_neg=['happy', 'hopeful', 'cheerful'],          
            intensifiers=frequency_weights,
            descriptor = {"Questionnair":"PHQ9",
              "Factor":"PHQ",
              "Ordinal":2,
              "Original":'Over the last 2 weeks, how often have you been bothered by the following problems? Feeling down, depressed or hopeless'
            },
            **kwargs
        )

class PHQ9Q3(_QMNLI):
    def __init__(self, **kwargs):
        super().__init__(
            context="Over the last 2 weeks, I {intensifier} had trouble falling asleep.",
            template="This sentence is {emotion}.",
            emo_neg=['depressive', 'sad', 'gloom'],
            emo_pos=["benign", 'legitimate',],
            intensifiers=frequency_weights,
            descriptor = {"Questionnair":"PHQ9",
              "Factor":"PHQ",
              "Ordinal":3,
              "Original":'Over the last 2 weeks, how often have you been bothered by the following problems? Trouble falling asleep, staying asleep, or sleeping too much'
            },
            **kwargs
        )

class PHQ9Q4(_QMNLI):
    def __init__(self, **kwargs):
        super().__init__(
            context="Over the last 2 weeks, I have been feeling {emotion}.",
            template="It is {intensifier} correct.",
            emo_pos=['tired', 'drained', 'fatigued'],
            emo_neg=['energized', 'refreshed', 'lively'],
            intensifiers=frequency_weights,
            descriptor = {"Questionnair":"PHQ9",
              "Factor":"PHQ",
              "Ordinal":4,
              "Original":'Over the last 2 weeks, how often have you been bothered by the following problems? Feeling tired or having little energy'
            },
            **kwargs
        )

class PHQ9Q5(_QMNLI):
    def __init__(self, **kwargs):
        super().__init__(
            context="Over the last 2 weeks, I had {emotion}.",
            template="It is {intensifier} correct.",
            emo_pos=['poor appetite', 'been overeating'],
            emo_neg=['healthy appetite', 'satisfying appetite'],
            intensifiers=frequency_weights,
            descriptor = {"Questionnair":"PHQ9",
              "Factor":"PHQ",
              "Ordinal":5,
              "Original":'Over the last 2 weeks, how often have you been bothered by the following problems? Poor appetite or overeating'
            },
            **kwargs
        )

class PHQ9Q6(_QMNLI):
    def __init__(self, **kwargs):
        super().__init__(
            context="Over the last 2 weeks, I feel {emotion}.",
            template="It is {intensifier} correct.",
            emo_pos=['I am a failure', 'I am a disappointment', 'I am underachieving', 'I let myself down', 'I let my family down'],
            emo_neg=['successful ', 'lucky', 'confident'],
            intensifiers=frequency_weights,
            descriptor = {"Questionnair":"PHQ9",
              "Factor":"PHQ",
              "Ordinal":6,
              "Original":'Over the last 2 weeks, how often have you been bothered by the following problems? Feeling bad about yourself - or that you’re a failure or have let yourself or your family down'
            },
            **kwargs
        )

class PHQ9Q7(_QMNLI):
    def __init__(self, **kwargs):
        super().__init__(
            context="Over the last 2 weeks, I {intensifier} had trouble concentrating.",
            template="This sentence is {emotion}.",
            emo_pos=["happy", 'joyful',],
            emo_neg=['depressive', 'sad', 'gloom'],
            intensifiers=frequency_weights,
            descriptor = {"Questionnair":"PHQ9",
              "Factor":"PHQ",
              "Ordinal":7,
              "Original":'Over the last 2 weeks, how often have you been bothered by the following problems? Trouble concentrating on things, such as reading the newspaper or watching television'
            },
            **kwargs
        )

class PHQ9Q8(_QMNLI):
    def __init__(self, **kwargs):
        super().__init__(
            context="Over the last 2 weeks, I move or speak {emotion}.",
            template="It is {intensifier} correct.",
            emo_pos=['fidgetly', 'slowly'],
            emo_neg=['normally', 'naturally'],
            intensifiers=frequency_weights,
            descriptor = {"Questionnair":"PHQ9",
              "Factor":"PHQ",
              "Ordinal":8,
              "Original":'Over the last 2 weeks, how often have you been bothered by the following problems? Moving or speaking so slowly that other people could have noticed. Or, the opposite - being so fidgety or restless that you have been moving around a lot more than usual'
            },
            **kwargs
        )

class PHQ9Q9(_QMNLI):
    def __init__(self, **kwargs):
        super().__init__(
            context="Over the last 2 weeks, I have {emotion} thoughts.",
            template="It is {intensifier} correct.",
            emo_pos=['suicidal', 'self destructive', 'deadly'],
            emo_neg=['happy', 'hopeful', 'positive'],
            intensifiers=frequency_weights,
            descriptor = {"Questionnair":"PHQ9",
              "Factor":"PHQ",
              "Ordinal":9,
              "Original":'Over the last 2 weeks, how often have you been bothered by the following problems? Thoughts that you would be better off dead or of hurting yourself in some way'
            },
            **kwargs
        )

phq2_qmnli = [PHQ9Q1, PHQ9Q2]
phq9_qmnli = [PHQ9Q1, PHQ9Q2, PHQ9Q3, PHQ9Q4, PHQ9Q5, PHQ9Q6, PHQ9Q7, PHQ9Q8, PHQ9Q9]
phq_qmnli = phq9_qmnli